@echo off

rem ##################################################
rem Initialize variables
rem ##################################################
SET BACKUP=1

rem ##################################################
rem Jump to starting point of script
rem ##################################################
goto START

:ERROR_ARGS
rem ##################################################
rem ERROR_ARGS function
rem ##################################################
echo Error:   Incorrect number of arguments supplied
echo.
goto USAGE

:HELP
rem ##################################################
rem HELP function
rem ##################################################
echo.
echo Info:    %0 converts an old Praesideo configuration file
echo          to the current Praesideo file format.
echo          A backup of the original configuration file
echo          is stored as "Configfile"-"Praesideo version".cfg
echo.
goto USAGE

:USAGE
rem ##################################################
rem USAGE function
rem ##################################################
echo Usage:   %0 "Configfile" (without extention .cfg)
echo Example: %0 Praesideo
echo.
echo Note:    This tool does not work for Praesideo 0.92 configuration files.
echo          If you want to convert a 0.92 configuration file,
echo          please convert it to 1.00 file format first by running:
echo          ConvertConfig_092-100.exe "Configfile"
echo          If you want to store your original 0.92 configuration file,
echo          rename "Configfile".bak before running %0.
goto END

:ERROR_NOFILE
rem ##################################################
rem ERROR_NOFILE function
rem ##################################################
echo Error:   Configfile %1.cfg does not exist
goto END

:ERROR_CONV
rem ##################################################
rem ERROR_CONV function
rem ##################################################
echo Error:   Conversion failed
echo          See %1.log for details
goto END

:ERROR_VERSION
rem ##################################################
rem ERROR_VERSION function
rem ##################################################
echo Error:   Unable to determine version (%ERRORLEVEL%)
goto END

:START
rem ##################################################
rem Start Execution
rem ##################################################

rem ##################################################
rem Check the command line
rem ##################################################
echo * Checking command line arguments
if [%1] == [/?] goto HELP
if [%1] == [] goto ERROR_ARGS

rem ##################################################
rem Check if specified configfile exists
rem ##################################################
echo * Checking configuration file
if not exist %1.cfg goto ERROR_NOFILE

rem ##################################################
rem Determine the file format version
rem ##################################################
echo * Checking configuration version
ConfigVersion %1.cfg > nul
if %ERRORLEVEL% == 10 goto C091
if %ERRORLEVEL% == 13 goto C100
if %ERRORLEVEL% == 14 (
  echo.
  echo Configuration file %1.cfg already is 1.10 format
  goto END
)
goto ERROR_VERSION

:C091
rem ##################################################
rem Convert from 0.91
rem ##################################################
if %BACKUP% == 1 (
  echo * Converting %1.cfg from 0.91
)
ConvertConfig_091-092.exe %1.cfg

rem ##################################################
rem Check if conversion succeeded
rem ##################################################
if not exist %1.bak goto ERROR_CONV
if not exist %1.log goto ERROR_CONV
if %BACKUP% == 1 (
  if exist %1-091.cfg del %1-091.cfg
  copy %1.bak %1-091.cfg > nul
  echo * 0.91 configuration saved as %1-091.cfg
  SET BACKUP=0
)
del %1.bak
del %1.log

:C092
rem ##################################################
rem Convert from 0.92
rem ##################################################
if %BACKUP% == 1 (
  echo * Converting %1.cfg from 0.92
)
ConvertConfig_092-100.exe %1.cfg

rem ##################################################
rem Check if conversion succeeded
rem ##################################################
if not exist %1.bak goto ERROR_CONV
if not exist %1.log goto ERROR_CONV
if %BACKUP% == 1 (
  if exist %1-092.cfg del %1-092.cfg
  copy %1.bak %1-092.cfg > nul
  echo * 0.92 configuration saved as %1-092.cfg
  SET BACKUP=0
)
del %1.bak
del %1.log

:C100
rem ##################################################
rem Convert from 1.00
rem ##################################################
if %BACKUP% == 1 (
  echo * Converting %1.cfg from 1.00
)
ConvertConfig_100-110.exe %1.cfg

rem ##################################################
rem Check if conversion succeeded
rem ##################################################
if not exist %1.bak goto ERROR_CONV
if not exist %1.log goto ERROR_CONV
if %BACKUP% == 1 (
  if exist %1-100.cfg del %1-100.cfg
  copy %1.bak %1-100.cfg > nul
  echo * 1.00 configuration saved as %1-100.cfg
  SET BACKUP=0
)
del %1.bak
del %1.log

rem ##################################################
rem Display end message
rem ##################################################
echo.
echo Configuration file %1.cfg converted to 1.10 format

:END
rem ##################################################
rem Stop execution
rem ##################################################
